# coding: utf-8

"""
    Timeline

    This feature allows an app to create and configure custom events that can show up in the timelines of certain CRM objects like contacts, companies, tickets, or deals. You'll find multiple use cases for this API in the sections below.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.timeline.api_client import ApiClient
from hubspot.crm.timeline.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class TokensApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, event_template_id, token_name, app_id, **kwargs):  # noqa: E501
        """Removes a token from the event template  # noqa: E501

        This will remove the token from an existing template. Existing events and CRM objects will still retain the token and its mapped object properties, but new ones will not.  The timeline will still display this property for older CRM objects if it's still referenced in the template `Markdown`. New events will not.  Any lists or reports referencing deleted tokens will no longer return new contacts, but old ones will still exist in the lists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(event_template_id, token_name, app_id, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param token_name: The token name. (required)
        :type token_name: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(event_template_id, token_name, app_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, event_template_id, token_name, app_id, **kwargs):  # noqa: E501
        """Removes a token from the event template  # noqa: E501

        This will remove the token from an existing template. Existing events and CRM objects will still retain the token and its mapped object properties, but new ones will not.  The timeline will still display this property for older CRM objects if it's still referenced in the template `Markdown`. New events will not.  Any lists or reports referencing deleted tokens will no longer return new contacts, but old ones will still exist in the lists.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(event_template_id, token_name, app_id, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param token_name: The token name. (required)
        :type token_name: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["event_template_id", "token_name", "app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'event_template_id' is set
        if self.api_client.client_side_validation and local_var_params.get("event_template_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `event_template_id` when calling `archive`")  # noqa: E501
        # verify the required parameter 'token_name' is set
        if self.api_client.client_side_validation and local_var_params.get("token_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `token_name` when calling `archive`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "event_template_id" in local_var_params:
            path_params["eventTemplateId"] = local_var_params["event_template_id"]  # noqa: E501
        if "token_name" in local_var_params:
            path_params["tokenName"] = local_var_params["token_name"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates/{eventTemplateId}/tokens/{tokenName}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, event_template_id, app_id, timeline_event_template_token, **kwargs):  # noqa: E501
        """Adds a token to an existing event template  # noqa: E501

        Once you've defined an event template, it's likely that you'll want to define tokens for it as well. You can do this on the event template itself or update individual tokens here.  Event type tokens allow you to attach custom data to events displayed in a timeline or used for list segmentation.  You can also use `objectPropertyName` to associate any CRM object properties. This will allow you to fully build out CRM objects.  Token names should be unique across the template.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(event_template_id, app_id, timeline_event_template_token, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_token: The new token definition. (required)
        :type timeline_event_template_token: TimelineEventTemplateToken
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimelineEventTemplateToken
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(event_template_id, app_id, timeline_event_template_token, **kwargs)  # noqa: E501

    def create_with_http_info(self, event_template_id, app_id, timeline_event_template_token, **kwargs):  # noqa: E501
        """Adds a token to an existing event template  # noqa: E501

        Once you've defined an event template, it's likely that you'll want to define tokens for it as well. You can do this on the event template itself or update individual tokens here.  Event type tokens allow you to attach custom data to events displayed in a timeline or used for list segmentation.  You can also use `objectPropertyName` to associate any CRM object properties. This will allow you to fully build out CRM objects.  Token names should be unique across the template.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(event_template_id, app_id, timeline_event_template_token, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_token: The new token definition. (required)
        :type timeline_event_template_token: TimelineEventTemplateToken
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimelineEventTemplateToken, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["event_template_id", "app_id", "timeline_event_template_token"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'event_template_id' is set
        if self.api_client.client_side_validation and local_var_params.get("event_template_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `event_template_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'timeline_event_template_token' is set
        if self.api_client.client_side_validation and local_var_params.get("timeline_event_template_token") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `timeline_event_template_token` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "event_template_id" in local_var_params:
            path_params["eventTemplateId"] = local_var_params["event_template_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "timeline_event_template_token" in local_var_params:
            body_params = local_var_params["timeline_event_template_token"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "TimelineEventTemplateToken",
        }

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates/{eventTemplateId}/tokens",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, event_template_id, token_name, app_id, timeline_event_template_token_update_request, **kwargs):  # noqa: E501
        """Updates an existing token on an event template  # noqa: E501

        This will update the existing token on an event template. Name and type can't be changed on existing tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(event_template_id, token_name, app_id, timeline_event_template_token_update_request, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param token_name: The token name. (required)
        :type token_name: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_token_update_request: The updated token definition. (required)
        :type timeline_event_template_token_update_request: TimelineEventTemplateTokenUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: TimelineEventTemplateToken
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(event_template_id, token_name, app_id, timeline_event_template_token_update_request, **kwargs)  # noqa: E501

    def update_with_http_info(self, event_template_id, token_name, app_id, timeline_event_template_token_update_request, **kwargs):  # noqa: E501
        """Updates an existing token on an event template  # noqa: E501

        This will update the existing token on an event template. Name and type can't be changed on existing tokens.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(event_template_id, token_name, app_id, timeline_event_template_token_update_request, async_req=True)
        >>> result = thread.get()

        :param event_template_id: The event template ID. (required)
        :type event_template_id: str
        :param token_name: The token name. (required)
        :type token_name: str
        :param app_id: The ID of the target app. (required)
        :type app_id: int
        :param timeline_event_template_token_update_request: The updated token definition. (required)
        :type timeline_event_template_token_update_request: TimelineEventTemplateTokenUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(TimelineEventTemplateToken, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["event_template_id", "token_name", "app_id", "timeline_event_template_token_update_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'event_template_id' is set
        if self.api_client.client_side_validation and local_var_params.get("event_template_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `event_template_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'token_name' is set
        if self.api_client.client_side_validation and local_var_params.get("token_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `token_name` when calling `update`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'timeline_event_template_token_update_request' is set
        if self.api_client.client_side_validation and local_var_params.get("timeline_event_template_token_update_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `timeline_event_template_token_update_request` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "event_template_id" in local_var_params:
            path_params["eventTemplateId"] = local_var_params["event_template_id"]  # noqa: E501
        if "token_name" in local_var_params:
            path_params["tokenName"] = local_var_params["token_name"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "timeline_event_template_token_update_request" in local_var_params:
            body_params = local_var_params["timeline_event_template_token_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "TimelineEventTemplateToken",
        }

        return self.api_client.call_api(
            "/integrators/timeline/v3/{appId}/event-templates/{eventTemplateId}/tokens/{tokenName}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



from ..discovery_base import DiscoveryBase

class Discovery(DiscoveryBase):
    @property
    def audit_logs(self):
        from .audit_logs.discovery import Discovery as AuditLogsDiscovery
        return AuditLogsDiscovery(self.config)

    @property
    def blogs(self):
        from .blogs.discovery import Discovery as BlogsDiscovery
        return BlogsDiscovery(self.config)

    @property
    def domains(self):
        from .domains.discovery import Discovery as DomainsDiscovery
        return DomainsDiscovery(self.config)

    @property
    def hubdb(self):
        from .hubdb.discovery import Discovery as HubdbDiscovery
        return HubdbDiscovery(self.config)

    @property
    def pages(self):
        from .pages.discovery import Discovery as PagesDiscovery
        return PagesDiscovery(self.config)

    @property
    def site_search(self):
        from .site_search.discovery import Discovery as SiteSearchDiscovery
        return SiteSearchDiscovery(self.config)

    @property
    def source_code(self):
        from .source_code.discovery import Discovery as SourceCodeDiscovery
        return SourceCodeDiscovery(self.config)

    @property
    def url_redirects(self):
        from .url_redirects.discovery import Discovery as UrlRedirectsDiscovery
        return UrlRedirectsDiscovery(self.config)



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicEmailFromDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"custom_reply_to": "str", "from_name": "str", "reply_to": "str"}

    attribute_map = {"custom_reply_to": "customReplyTo", "from_name": "fromName", "reply_to": "replyTo"}

    def __init__(self, custom_reply_to=None, from_name=None, reply_to=None, local_vars_configuration=None):  # noqa: E501
        """PublicEmailFromDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._custom_reply_to = None
        self._from_name = None
        self._reply_to = None
        self.discriminator = None

        if custom_reply_to is not None:
            self.custom_reply_to = custom_reply_to
        if from_name is not None:
            self.from_name = from_name
        if reply_to is not None:
            self.reply_to = reply_to

    @property
    def custom_reply_to(self):
        """Gets the custom_reply_to of this PublicEmailFromDetails.  # noqa: E501

        The reply to recipients will see.  # noqa: E501

        :return: The custom_reply_to of this PublicEmailFromDetails.  # noqa: E501
        :rtype: str
        """
        return self._custom_reply_to

    @custom_reply_to.setter
    def custom_reply_to(self, custom_reply_to):
        """Sets the custom_reply_to of this PublicEmailFromDetails.

        The reply to recipients will see.  # noqa: E501

        :param custom_reply_to: The custom_reply_to of this PublicEmailFromDetails.  # noqa: E501
        :type custom_reply_to: str
        """

        self._custom_reply_to = custom_reply_to

    @property
    def from_name(self):
        """Gets the from_name of this PublicEmailFromDetails.  # noqa: E501

        The name recipients will see.  # noqa: E501

        :return: The from_name of this PublicEmailFromDetails.  # noqa: E501
        :rtype: str
        """
        return self._from_name

    @from_name.setter
    def from_name(self, from_name):
        """Sets the from_name of this PublicEmailFromDetails.

        The name recipients will see.  # noqa: E501

        :param from_name: The from_name of this PublicEmailFromDetails.  # noqa: E501
        :type from_name: str
        """

        self._from_name = from_name

    @property
    def reply_to(self):
        """Gets the reply_to of this PublicEmailFromDetails.  # noqa: E501

        The from address and reply to email address (if no customReplyTo defined) recipients will see.  # noqa: E501

        :return: The reply_to of this PublicEmailFromDetails.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this PublicEmailFromDetails.

        The from address and reply to email address (if no customReplyTo defined) recipients will see.  # noqa: E501

        :param reply_to: The reply_to of this PublicEmailFromDetails.  # noqa: E501
        :type reply_to: str
        """

        self._reply_to = reply_to

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEmailFromDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEmailFromDetails):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.crm.objects as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def basic_api(self) -> api_client.BasicApi:
        return self._configure_api_client(api_client, "BasicApi")

    @property
    def batch_api(self) -> api_client.BatchApi:
        return self._configure_api_client(api_client, "BatchApi")

    @property
    def search_api(self) -> api_client.SearchApi:
        return self._configure_api_client(api_client, "SearchApi")

    @property
    def calls(self):
        from .calls.discovery import Discovery as CallsDiscovery
        return CallsDiscovery(self.config)

    @property
    def communications(self):
        from .communications.discovery import Discovery as CommunicationsDiscovery
        return CommunicationsDiscovery(self.config)

    @property
    def deal_splits(self):
        from .deal_splits.discovery import Discovery as DealSplitsDiscovery
        return DealSplitsDiscovery(self.config)

    @property
    def emails(self):
        from .emails.discovery import Discovery as EmailsDiscovery
        return EmailsDiscovery(self.config)

    @property
    def feedback_submissions(self):
        from .feedback_submissions.discovery import Discovery as FeedbackSubmissionsDiscovery
        return FeedbackSubmissionsDiscovery(self.config)

    @property
    def goals(self):
        from .goals.discovery import Discovery as GoalsDiscovery
        return GoalsDiscovery(self.config)

    @property
    def leads(self):
        from .leads.discovery import Discovery as LeadsDiscovery
        return LeadsDiscovery(self.config)

    @property
    def meetings(self):
        from .meetings.discovery import Discovery as MeetingsDiscovery
        return MeetingsDiscovery(self.config)

    @property
    def notes(self):
        from .notes.discovery import Discovery as NotesDiscovery
        return NotesDiscovery(self.config)

    @property
    def postal_mail(self):
        from .postal_mail.discovery import Discovery as PostalMailDiscovery
        return PostalMailDiscovery(self.config)

    @property
    def tasks(self):
        from .tasks.discovery import Discovery as TasksDiscovery
        return TasksDiscovery(self.config)

    @property
    def taxes(self):
        from .taxes.discovery import Discovery as TaxesDiscovery
        return TaxesDiscovery(self.config)

    def get_all(self, object_type, **kwargs):
        return self.fetch_all(object_type, **kwargs)

    def fetch_all(self, object_type, **kwargs):
        results = []
        after = None
        PAGE_MAX_SIZE = 100

        while True:
            page = self.basic_api.get_page(object_type, after=after, limit=PAGE_MAX_SIZE, **kwargs)
            results.extend(page.results)
            if page.paging is None:
                break
            after = page.paging.next.after

        return results



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class PublicEmailContent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "smart_fields": "dict[str, object]",
        "theme_settings_values": "dict[str, object]",
        "flex_areas": "dict[str, object]",
        "widgets": "dict[str, object]",
        "plain_text_version": "str",
        "template_path": "str",
        "widget_containers": "dict[str, object]",
        "style_settings": "PublicEmailStyleSettings",
    }

    attribute_map = {
        "smart_fields": "smartFields",
        "theme_settings_values": "themeSettingsValues",
        "flex_areas": "flexAreas",
        "widgets": "widgets",
        "plain_text_version": "plainTextVersion",
        "template_path": "templatePath",
        "widget_containers": "widgetContainers",
        "style_settings": "styleSettings",
    }

    def __init__(
        self,
        smart_fields=None,
        theme_settings_values=None,
        flex_areas=None,
        widgets=None,
        plain_text_version=None,
        template_path=None,
        widget_containers=None,
        style_settings=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicEmailContent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._smart_fields = None
        self._theme_settings_values = None
        self._flex_areas = None
        self._widgets = None
        self._plain_text_version = None
        self._template_path = None
        self._widget_containers = None
        self._style_settings = None
        self.discriminator = None

        if smart_fields is not None:
            self.smart_fields = smart_fields
        if theme_settings_values is not None:
            self.theme_settings_values = theme_settings_values
        if flex_areas is not None:
            self.flex_areas = flex_areas
        if widgets is not None:
            self.widgets = widgets
        if plain_text_version is not None:
            self.plain_text_version = plain_text_version
        if template_path is not None:
            self.template_path = template_path
        if widget_containers is not None:
            self.widget_containers = widget_containers
        if style_settings is not None:
            self.style_settings = style_settings

    @property
    def smart_fields(self):
        """Gets the smart_fields of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The smart_fields of this PublicEmailContent.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._smart_fields

    @smart_fields.setter
    def smart_fields(self, smart_fields):
        """Sets the smart_fields of this PublicEmailContent.

          # noqa: E501

        :param smart_fields: The smart_fields of this PublicEmailContent.  # noqa: E501
        :type smart_fields: dict[str, object]
        """

        self._smart_fields = smart_fields

    @property
    def theme_settings_values(self):
        """Gets the theme_settings_values of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The theme_settings_values of this PublicEmailContent.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._theme_settings_values

    @theme_settings_values.setter
    def theme_settings_values(self, theme_settings_values):
        """Sets the theme_settings_values of this PublicEmailContent.

          # noqa: E501

        :param theme_settings_values: The theme_settings_values of this PublicEmailContent.  # noqa: E501
        :type theme_settings_values: dict[str, object]
        """

        self._theme_settings_values = theme_settings_values

    @property
    def flex_areas(self):
        """Gets the flex_areas of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The flex_areas of this PublicEmailContent.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._flex_areas

    @flex_areas.setter
    def flex_areas(self, flex_areas):
        """Sets the flex_areas of this PublicEmailContent.

          # noqa: E501

        :param flex_areas: The flex_areas of this PublicEmailContent.  # noqa: E501
        :type flex_areas: dict[str, object]
        """

        self._flex_areas = flex_areas

    @property
    def widgets(self):
        """Gets the widgets of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The widgets of this PublicEmailContent.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._widgets

    @widgets.setter
    def widgets(self, widgets):
        """Sets the widgets of this PublicEmailContent.

          # noqa: E501

        :param widgets: The widgets of this PublicEmailContent.  # noqa: E501
        :type widgets: dict[str, object]
        """

        self._widgets = widgets

    @property
    def plain_text_version(self):
        """Gets the plain_text_version of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The plain_text_version of this PublicEmailContent.  # noqa: E501
        :rtype: str
        """
        return self._plain_text_version

    @plain_text_version.setter
    def plain_text_version(self, plain_text_version):
        """Sets the plain_text_version of this PublicEmailContent.

          # noqa: E501

        :param plain_text_version: The plain_text_version of this PublicEmailContent.  # noqa: E501
        :type plain_text_version: str
        """

        self._plain_text_version = plain_text_version

    @property
    def template_path(self):
        """Gets the template_path of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The template_path of this PublicEmailContent.  # noqa: E501
        :rtype: str
        """
        return self._template_path

    @template_path.setter
    def template_path(self, template_path):
        """Sets the template_path of this PublicEmailContent.

          # noqa: E501

        :param template_path: The template_path of this PublicEmailContent.  # noqa: E501
        :type template_path: str
        """

        self._template_path = template_path

    @property
    def widget_containers(self):
        """Gets the widget_containers of this PublicEmailContent.  # noqa: E501

          # noqa: E501

        :return: The widget_containers of this PublicEmailContent.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._widget_containers

    @widget_containers.setter
    def widget_containers(self, widget_containers):
        """Sets the widget_containers of this PublicEmailContent.

          # noqa: E501

        :param widget_containers: The widget_containers of this PublicEmailContent.  # noqa: E501
        :type widget_containers: dict[str, object]
        """

        self._widget_containers = widget_containers

    @property
    def style_settings(self):
        """Gets the style_settings of this PublicEmailContent.  # noqa: E501


        :return: The style_settings of this PublicEmailContent.  # noqa: E501
        :rtype: PublicEmailStyleSettings
        """
        return self._style_settings

    @style_settings.setter
    def style_settings(self, style_settings):
        """Sets the style_settings of this PublicEmailContent.


        :param style_settings: The style_settings of this PublicEmailContent.  # noqa: E501
        :type style_settings: PublicEmailStyleSettings
        """

        self._style_settings = style_settings

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicEmailContent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicEmailContent):
            return True

        return self.to_dict() != other.to_dict()



from ..discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def actions(self):
        from .actions.discovery import Discovery as ActionsDiscovery
        return ActionsDiscovery(self.config)



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class ObjectTypeDefinitionLabels(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"plural": "str", "singular": "str"}

    attribute_map = {"plural": "plural", "singular": "singular"}

    def __init__(self, plural=None, singular=None, local_vars_configuration=None):  # noqa: E501
        """ObjectTypeDefinitionLabels - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._plural = None
        self._singular = None
        self.discriminator = None

        if plural is not None:
            self.plural = plural
        if singular is not None:
            self.singular = singular

    @property
    def plural(self):
        """Gets the plural of this ObjectTypeDefinitionLabels.  # noqa: E501

        The word for multiple objects. (There’s no way to change this later.)  # noqa: E501

        :return: The plural of this ObjectTypeDefinitionLabels.  # noqa: E501
        :rtype: str
        """
        return self._plural

    @plural.setter
    def plural(self, plural):
        """Sets the plural of this ObjectTypeDefinitionLabels.

        The word for multiple objects. (There’s no way to change this later.)  # noqa: E501

        :param plural: The plural of this ObjectTypeDefinitionLabels.  # noqa: E501
        :type plural: str
        """

        self._plural = plural

    @property
    def singular(self):
        """Gets the singular of this ObjectTypeDefinitionLabels.  # noqa: E501

        The word for one object. (There’s no way to change this later.)  # noqa: E501

        :return: The singular of this ObjectTypeDefinitionLabels.  # noqa: E501
        :rtype: str
        """
        return self._singular

    @singular.setter
    def singular(self, singular):
        """Sets the singular of this ObjectTypeDefinitionLabels.

        The word for one object. (There’s no way to change this later.)  # noqa: E501

        :param singular: The singular of this ObjectTypeDefinitionLabels.  # noqa: E501
        :type singular: str
        """

        self._singular = singular

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ObjectTypeDefinitionLabels):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ObjectTypeDefinitionLabels):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.lists.api_client import ApiClient
from hubspot.crm.lists.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class ListsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create(self, list_create_request, **kwargs):  # noqa: E501
        """Create List  # noqa: E501

        Create a new list with the provided object list definition.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(list_create_request, async_req=True)
        >>> result = thread.get()

        :param list_create_request: (required)
        :type list_create_request: ListCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListCreateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(list_create_request, **kwargs)  # noqa: E501

    def create_with_http_info(self, list_create_request, **kwargs):  # noqa: E501
        """Create List  # noqa: E501

        Create a new list with the provided object list definition.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(list_create_request, async_req=True)
        >>> result = thread.get()

        :param list_create_request: (required)
        :type list_create_request: ListCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListCreateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_create_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_create_request' is set
        if self.api_client.client_side_validation and local_var_params.get("list_create_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_create_request` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "list_create_request" in local_var_params:
            body_params = local_var_params["list_create_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListCreateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def do_search(self, list_search_request, **kwargs):  # noqa: E501
        """Search Lists  # noqa: E501

        Search lists by list name or page through all lists by providing an empty `query` value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.do_search(list_search_request, async_req=True)
        >>> result = thread.get()

        :param list_search_request: (required)
        :type list_search_request: ListSearchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListSearchResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.do_search_with_http_info(list_search_request, **kwargs)  # noqa: E501

    def do_search_with_http_info(self, list_search_request, **kwargs):  # noqa: E501
        """Search Lists  # noqa: E501

        Search lists by list name or page through all lists by providing an empty `query` value.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.do_search_with_http_info(list_search_request, async_req=True)
        >>> result = thread.get()

        :param list_search_request: (required)
        :type list_search_request: ListSearchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListSearchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_search_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method do_search" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_search_request' is set
        if self.api_client.client_side_validation and local_var_params.get("list_search_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_search_request` when calling `do_search`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "list_search_request" in local_var_params:
            body_params = local_var_params["list_search_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListSearchResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/search",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, **kwargs):  # noqa: E501
        """Fetch Multiple Lists  # noqa: E501

        Fetch multiple lists in a single request by **ILS list ID**. The response will include the definitions of all lists that exist for the `listIds` provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(async_req=True)
        >>> result = thread.get()

        :param list_ids: The **ILS IDs** of the lists to fetch.
        :type list_ids: list[str]
        :param include_filters: A flag indicating whether or not the response object list definitions should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListsByIdResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(**kwargs)  # noqa: E501

    def get_all_with_http_info(self, **kwargs):  # noqa: E501
        """Fetch Multiple Lists  # noqa: E501

        Fetch multiple lists in a single request by **ILS list ID**. The response will include the definitions of all lists that exist for the `listIds` provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(async_req=True)
        >>> result = thread.get()

        :param list_ids: The **ILS IDs** of the lists to fetch.
        :type list_ids: list[str]
        :param include_filters: A flag indicating whether or not the response object list definitions should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListsByIdResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_ids", "include_filters"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("list_ids") is not None:  # noqa: E501
            query_params.append(("listIds", local_var_params["list_ids"]))  # noqa: E501
            collection_formats["listIds"] = "multi"  # noqa: E501
        if local_var_params.get("include_filters") is not None:  # noqa: E501
            query_params.append(("includeFilters", local_var_params["include_filters"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListsByIdResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, list_id, **kwargs):  # noqa: E501
        """Fetch List by ID  # noqa: E501

        Fetch a single list by **ILS list ID**.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to fetch. (required)
        :type list_id: str
        :param include_filters: A flag indicating whether or not the response object list definition should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListFetchResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(list_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Fetch List by ID  # noqa: E501

        Fetch a single list by **ILS list ID**.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to fetch. (required)
        :type list_id: str
        :param include_filters: A flag indicating whether or not the response object list definition should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListFetchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "include_filters"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("include_filters") is not None:  # noqa: E501
            query_params.append(("includeFilters", local_var_params["include_filters"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListFetchResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_name(self, list_name, object_type_id, **kwargs):  # noqa: E501
        """Fetch List by Name  # noqa: E501

        Fetch a single list by list name and object type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_name(list_name, object_type_id, async_req=True)
        >>> result = thread.get()

        :param list_name: The name of the list to fetch. This is **not** case sensitive. (required)
        :type list_name: str
        :param object_type_id: The object type ID of the object types stored by the list to fetch. For example, `0-1` for a `CONTACT` list. (required)
        :type object_type_id: str
        :param include_filters: A flag indicating whether or not the response object list definition should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListFetchResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_name_with_http_info(list_name, object_type_id, **kwargs)  # noqa: E501

    def get_by_name_with_http_info(self, list_name, object_type_id, **kwargs):  # noqa: E501
        """Fetch List by Name  # noqa: E501

        Fetch a single list by list name and object type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_name_with_http_info(list_name, object_type_id, async_req=True)
        >>> result = thread.get()

        :param list_name: The name of the list to fetch. This is **not** case sensitive. (required)
        :type list_name: str
        :param object_type_id: The object type ID of the object types stored by the list to fetch. For example, `0-1` for a `CONTACT` list. (required)
        :type object_type_id: str
        :param include_filters: A flag indicating whether or not the response object list definition should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListFetchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_name", "object_type_id", "include_filters"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_name" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_name' is set
        if self.api_client.client_side_validation and local_var_params.get("list_name") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_name` when calling `get_by_name`")  # noqa: E501
        # verify the required parameter 'object_type_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type_id` when calling `get_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_name" in local_var_params:
            path_params["listName"] = local_var_params["list_name"]  # noqa: E501
        if "object_type_id" in local_var_params:
            path_params["objectTypeId"] = local_var_params["object_type_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("include_filters") is not None:  # noqa: E501
            query_params.append(("includeFilters", local_var_params["include_filters"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListFetchResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/object-type-id/{objectTypeId}/name/{listName}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def remove(self, list_id, **kwargs):  # noqa: E501
        """Delete a List  # noqa: E501

        Delete a list by **ILS list ID**. Lists deleted through this endpoint can be restored up to 90-days following the delete. After 90-days, the list is purged and can no longer be restored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to delete. (required)
        :type list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.remove_with_http_info(list_id, **kwargs)  # noqa: E501

    def remove_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Delete a List  # noqa: E501

        Delete a list by **ILS list ID**. Lists deleted through this endpoint can be restored up to 90-days following the delete. After 90-days, the list is purged and can no longer be restored.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to delete. (required)
        :type list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["list_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method remove" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `remove`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def restore(self, list_id, **kwargs):  # noqa: E501
        """Restore a List  # noqa: E501

        Restore a previously deleted list by **ILS list ID**. Deleted lists are eligible to be restored up-to 90-days after the list has been deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.restore(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to restore. (required)
        :type list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.restore_with_http_info(list_id, **kwargs)  # noqa: E501

    def restore_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Restore a List  # noqa: E501

        Restore a previously deleted list by **ILS list ID**. Deleted lists are eligible to be restored up-to 90-days after the list has been deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.restore_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to restore. (required)
        :type list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["list_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method restore" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `restore`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/restore",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_list_filters(self, list_id, list_filter_update_request, **kwargs):  # noqa: E501
        """Update List Filter Definition  # noqa: E501

        Update the filter branch definition of a `DYNAMIC` list. Once updated, the list memberships will be re-evaluated and updated to match the new definition.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_list_filters(list_id, list_filter_update_request, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to update. (required)
        :type list_id: str
        :param list_filter_update_request: (required)
        :type list_filter_update_request: ListFilterUpdateRequest
        :param enroll_objects_in_workflows: A flag indicating whether or not the memberships added to the list as a result of the filter change should be enrolled in workflows that are relevant to this list.
        :type enroll_objects_in_workflows: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListUpdateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.update_list_filters_with_http_info(list_id, list_filter_update_request, **kwargs)  # noqa: E501

    def update_list_filters_with_http_info(self, list_id, list_filter_update_request, **kwargs):  # noqa: E501
        """Update List Filter Definition  # noqa: E501

        Update the filter branch definition of a `DYNAMIC` list. Once updated, the list memberships will be re-evaluated and updated to match the new definition.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_list_filters_with_http_info(list_id, list_filter_update_request, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to update. (required)
        :type list_id: str
        :param list_filter_update_request: (required)
        :type list_filter_update_request: ListFilterUpdateRequest
        :param enroll_objects_in_workflows: A flag indicating whether or not the memberships added to the list as a result of the filter change should be enrolled in workflows that are relevant to this list.
        :type enroll_objects_in_workflows: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListUpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "list_filter_update_request", "enroll_objects_in_workflows"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_list_filters" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `update_list_filters`")  # noqa: E501
        # verify the required parameter 'list_filter_update_request' is set
        if self.api_client.client_side_validation and local_var_params.get("list_filter_update_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_filter_update_request` when calling `update_list_filters`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("enroll_objects_in_workflows") is not None:  # noqa: E501
            query_params.append(("enrollObjectsInWorkflows", local_var_params["enroll_objects_in_workflows"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "list_filter_update_request" in local_var_params:
            body_params = local_var_params["list_filter_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListUpdateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/update-list-filters",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_name(self, list_id, **kwargs):  # noqa: E501
        """Update List Name  # noqa: E501

        Update the name of a list. The name must be globally unique relative to all other public lists in the portal.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_name(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to update. (required)
        :type list_id: str
        :param list_name: The name to update the list to.
        :type list_name: str
        :param include_filters: A flag indicating whether or not the response object list definition should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListUpdateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.update_name_with_http_info(list_id, **kwargs)  # noqa: E501

    def update_name_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Update List Name  # noqa: E501

        Update the name of a list. The name must be globally unique relative to all other public lists in the portal.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_name_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list to update. (required)
        :type list_id: str
        :param list_name: The name to update the list to.
        :type list_name: str
        :param include_filters: A flag indicating whether or not the response object list definition should include a filter branch definition. By default, object list definitions will not have their filter branch definitions included in the response.
        :type include_filters: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListUpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "list_name", "include_filters"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_name" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `update_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("list_name") is not None:  # noqa: E501
            query_params.append(("listName", local_var_params["list_name"]))  # noqa: E501
        if local_var_params.get("include_filters") is not None:  # noqa: E501
            query_params.append(("includeFilters", local_var_params["include_filters"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ListUpdateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/update-list-name",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

# flake8: noqa

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.files.api.files_api import FilesApi
from hubspot.files.api.folders_api import FoldersApi

# import ApiClient
from hubspot.files.api_client import ApiClient
from hubspot.files.configuration import Configuration
from hubspot.files.exceptions import OpenApiException
from hubspot.files.exceptions import ApiTypeError
from hubspot.files.exceptions import ApiValueError
from hubspot.files.exceptions import ApiKeyError
from hubspot.files.exceptions import ApiAttributeError
from hubspot.files.exceptions import ApiException

# import models into sdk package
from hubspot.files.models.collection_response_file import CollectionResponseFile
from hubspot.files.models.collection_response_folder import CollectionResponseFolder
from hubspot.files.models.error import Error
from hubspot.files.models.error_detail import ErrorDetail
from hubspot.files.models.file import File
from hubspot.files.models.file_action_response import FileActionResponse
from hubspot.files.models.file_stat import FileStat
from hubspot.files.models.file_update_input import FileUpdateInput
from hubspot.files.models.folder import Folder
from hubspot.files.models.folder_action_response import FolderActionResponse
from hubspot.files.models.folder_input import FolderInput
from hubspot.files.models.folder_update_input import FolderUpdateInput
from hubspot.files.models.folder_update_input_with_id import FolderUpdateInputWithId
from hubspot.files.models.folder_update_task_locator import FolderUpdateTaskLocator
from hubspot.files.models.import_from_url_input import ImportFromUrlInput
from hubspot.files.models.import_from_url_task_locator import ImportFromUrlTaskLocator
from hubspot.files.models.next_page import NextPage
from hubspot.files.models.paging import Paging
from hubspot.files.models.previous_page import PreviousPage
from hubspot.files.models.signed_url import SignedUrl
from hubspot.files.models.standard_error import StandardError



# coding: utf-8

"""
    Imports

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.imports.configuration import Configuration


class PublicImportResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "import_template": "ImportTemplate",
        "created_at": "datetime",
        "metadata": "PublicImportMetadata",
        "import_request_json": "object",
        "import_source": "str",
        "import_name": "str",
        "state": "str",
        "id": "str",
        "opt_out_import": "bool",
        "mapped_object_type_ids": "list[str]",
        "updated_at": "datetime",
    }

    attribute_map = {
        "import_template": "importTemplate",
        "created_at": "createdAt",
        "metadata": "metadata",
        "import_request_json": "importRequestJson",
        "import_source": "importSource",
        "import_name": "importName",
        "state": "state",
        "id": "id",
        "opt_out_import": "optOutImport",
        "mapped_object_type_ids": "mappedObjectTypeIds",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        import_template=None,
        created_at=None,
        metadata=None,
        import_request_json=None,
        import_source=None,
        import_name=None,
        state=None,
        id=None,
        opt_out_import=None,
        mapped_object_type_ids=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicImportResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._import_template = None
        self._created_at = None
        self._metadata = None
        self._import_request_json = None
        self._import_source = None
        self._import_name = None
        self._state = None
        self._id = None
        self._opt_out_import = None
        self._mapped_object_type_ids = None
        self._updated_at = None
        self.discriminator = None

        if import_template is not None:
            self.import_template = import_template
        self.created_at = created_at
        self.metadata = metadata
        if import_request_json is not None:
            self.import_request_json = import_request_json
        if import_source is not None:
            self.import_source = import_source
        if import_name is not None:
            self.import_name = import_name
        self.state = state
        self.id = id
        self.opt_out_import = opt_out_import
        self.mapped_object_type_ids = mapped_object_type_ids
        self.updated_at = updated_at

    @property
    def import_template(self):
        """Gets the import_template of this PublicImportResponse.  # noqa: E501


        :return: The import_template of this PublicImportResponse.  # noqa: E501
        :rtype: ImportTemplate
        """
        return self._import_template

    @import_template.setter
    def import_template(self, import_template):
        """Sets the import_template of this PublicImportResponse.


        :param import_template: The import_template of this PublicImportResponse.  # noqa: E501
        :type import_template: ImportTemplate
        """

        self._import_template = import_template

    @property
    def created_at(self):
        """Gets the created_at of this PublicImportResponse.  # noqa: E501


        :return: The created_at of this PublicImportResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicImportResponse.


        :param created_at: The created_at of this PublicImportResponse.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def metadata(self):
        """Gets the metadata of this PublicImportResponse.  # noqa: E501


        :return: The metadata of this PublicImportResponse.  # noqa: E501
        :rtype: PublicImportMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this PublicImportResponse.


        :param metadata: The metadata of this PublicImportResponse.  # noqa: E501
        :type metadata: PublicImportMetadata
        """
        if self.local_vars_configuration.client_side_validation and metadata is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata`, must not be `None`")  # noqa: E501

        self._metadata = metadata

    @property
    def import_request_json(self):
        """Gets the import_request_json of this PublicImportResponse.  # noqa: E501


        :return: The import_request_json of this PublicImportResponse.  # noqa: E501
        :rtype: object
        """
        return self._import_request_json

    @import_request_json.setter
    def import_request_json(self, import_request_json):
        """Sets the import_request_json of this PublicImportResponse.


        :param import_request_json: The import_request_json of this PublicImportResponse.  # noqa: E501
        :type import_request_json: object
        """

        self._import_request_json = import_request_json

    @property
    def import_source(self):
        """Gets the import_source of this PublicImportResponse.  # noqa: E501


        :return: The import_source of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._import_source

    @import_source.setter
    def import_source(self, import_source):
        """Sets the import_source of this PublicImportResponse.


        :param import_source: The import_source of this PublicImportResponse.  # noqa: E501
        :type import_source: str
        """
        allowed_values = ["API", "CRM_UI", "IMPORT", "MOBILE_ANDROID", "MOBILE_IOS", "SALESFORCE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and import_source not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `import_source` ({0}), must be one of {1}".format(import_source, allowed_values))  # noqa: E501

        self._import_source = import_source

    @property
    def import_name(self):
        """Gets the import_name of this PublicImportResponse.  # noqa: E501


        :return: The import_name of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._import_name

    @import_name.setter
    def import_name(self, import_name):
        """Sets the import_name of this PublicImportResponse.


        :param import_name: The import_name of this PublicImportResponse.  # noqa: E501
        :type import_name: str
        """

        self._import_name = import_name

    @property
    def state(self):
        """Gets the state of this PublicImportResponse.  # noqa: E501

        The status of the import.  # noqa: E501

        :return: The state of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PublicImportResponse.

        The status of the import.  # noqa: E501

        :param state: The state of this PublicImportResponse.  # noqa: E501
        :type state: str
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501
        allowed_values = ["STARTED", "PROCESSING", "DONE", "FAILED", "CANCELED", "DEFERRED", "REVERTED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `state` ({0}), must be one of {1}".format(state, allowed_values))  # noqa: E501

        self._state = state

    @property
    def id(self):
        """Gets the id of this PublicImportResponse.  # noqa: E501


        :return: The id of this PublicImportResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicImportResponse.


        :param id: The id of this PublicImportResponse.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def opt_out_import(self):
        """Gets the opt_out_import of this PublicImportResponse.  # noqa: E501

        Whether or not the import is a list of people disqualified from receiving emails.  # noqa: E501

        :return: The opt_out_import of this PublicImportResponse.  # noqa: E501
        :rtype: bool
        """
        return self._opt_out_import

    @opt_out_import.setter
    def opt_out_import(self, opt_out_import):
        """Sets the opt_out_import of this PublicImportResponse.

        Whether or not the import is a list of people disqualified from receiving emails.  # noqa: E501

        :param opt_out_import: The opt_out_import of this PublicImportResponse.  # noqa: E501
        :type opt_out_import: bool
        """
        if self.local_vars_configuration.client_side_validation and opt_out_import is None:  # noqa: E501
            raise ValueError("Invalid value for `opt_out_import`, must not be `None`")  # noqa: E501

        self._opt_out_import = opt_out_import

    @property
    def mapped_object_type_ids(self):
        """Gets the mapped_object_type_ids of this PublicImportResponse.  # noqa: E501


        :return: The mapped_object_type_ids of this PublicImportResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._mapped_object_type_ids

    @mapped_object_type_ids.setter
    def mapped_object_type_ids(self, mapped_object_type_ids):
        """Sets the mapped_object_type_ids of this PublicImportResponse.


        :param mapped_object_type_ids: The mapped_object_type_ids of this PublicImportResponse.  # noqa: E501
        :type mapped_object_type_ids: list[str]
        """
        if self.local_vars_configuration.client_side_validation and mapped_object_type_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `mapped_object_type_ids`, must not be `None`")  # noqa: E501

        self._mapped_object_type_ids = mapped_object_type_ids

    @property
    def updated_at(self):
        """Gets the updated_at of this PublicImportResponse.  # noqa: E501


        :return: The updated_at of this PublicImportResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PublicImportResponse.


        :param updated_at: The updated_at of this PublicImportResponse.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicImportResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicImportResponse):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.cms.pages as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def landing_pages_api(self) -> api_client.LandingPagesApi:
        return self._configure_api_client(api_client, "LandingPagesApi")

    @property
    def site_pages_api(self) -> api_client.SitePagesApi:
        return self._configure_api_client(api_client, "SitePagesApi")



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class HubSpotFormDefinitionPatchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "field_groups": "list[FieldGroup]",
        "archived": "bool",
        "configuration": "HubSpotFormConfiguration",
        "name": "str",
        "legal_consent_options": "HubSpotFormDefinitionAllOfLegalConsentOptions",
        "display_options": "FormDisplayOptions",
    }

    attribute_map = {
        "field_groups": "fieldGroups",
        "archived": "archived",
        "configuration": "configuration",
        "name": "name",
        "legal_consent_options": "legalConsentOptions",
        "display_options": "displayOptions",
    }

    def __init__(self, field_groups=None, archived=None, configuration=None, name=None, legal_consent_options=None, display_options=None, local_vars_configuration=None):  # noqa: E501
        """HubSpotFormDefinitionPatchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._field_groups = None
        self._archived = None
        self._configuration = None
        self._name = None
        self._legal_consent_options = None
        self._display_options = None
        self.discriminator = None

        if field_groups is not None:
            self.field_groups = field_groups
        if archived is not None:
            self.archived = archived
        if configuration is not None:
            self.configuration = configuration
        if name is not None:
            self.name = name
        if legal_consent_options is not None:
            self.legal_consent_options = legal_consent_options
        if display_options is not None:
            self.display_options = display_options

    @property
    def field_groups(self):
        """Gets the field_groups of this HubSpotFormDefinitionPatchRequest.  # noqa: E501

        The fields in the form, grouped in rows.  # noqa: E501

        :return: The field_groups of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :rtype: list[FieldGroup]
        """
        return self._field_groups

    @field_groups.setter
    def field_groups(self, field_groups):
        """Sets the field_groups of this HubSpotFormDefinitionPatchRequest.

        The fields in the form, grouped in rows.  # noqa: E501

        :param field_groups: The field_groups of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :type field_groups: list[FieldGroup]
        """

        self._field_groups = field_groups

    @property
    def archived(self):
        """Gets the archived of this HubSpotFormDefinitionPatchRequest.  # noqa: E501

        Whether this form is archived.  # noqa: E501

        :return: The archived of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this HubSpotFormDefinitionPatchRequest.

        Whether this form is archived.  # noqa: E501

        :param archived: The archived of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :type archived: bool
        """

        self._archived = archived

    @property
    def configuration(self):
        """Gets the configuration of this HubSpotFormDefinitionPatchRequest.  # noqa: E501


        :return: The configuration of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :rtype: HubSpotFormConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this HubSpotFormDefinitionPatchRequest.


        :param configuration: The configuration of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :type configuration: HubSpotFormConfiguration
        """

        self._configuration = configuration

    @property
    def name(self):
        """Gets the name of this HubSpotFormDefinitionPatchRequest.  # noqa: E501

        The name of the form. Expected to be unique for a hub.  # noqa: E501

        :return: The name of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this HubSpotFormDefinitionPatchRequest.

        The name of the form. Expected to be unique for a hub.  # noqa: E501

        :param name: The name of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def legal_consent_options(self):
        """Gets the legal_consent_options of this HubSpotFormDefinitionPatchRequest.  # noqa: E501


        :return: The legal_consent_options of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :rtype: HubSpotFormDefinitionAllOfLegalConsentOptions
        """
        return self._legal_consent_options

    @legal_consent_options.setter
    def legal_consent_options(self, legal_consent_options):
        """Sets the legal_consent_options of this HubSpotFormDefinitionPatchRequest.


        :param legal_consent_options: The legal_consent_options of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :type legal_consent_options: HubSpotFormDefinitionAllOfLegalConsentOptions
        """

        self._legal_consent_options = legal_consent_options

    @property
    def display_options(self):
        """Gets the display_options of this HubSpotFormDefinitionPatchRequest.  # noqa: E501


        :return: The display_options of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :rtype: FormDisplayOptions
        """
        return self._display_options

    @display_options.setter
    def display_options(self, display_options):
        """Sets the display_options of this HubSpotFormDefinitionPatchRequest.


        :param display_options: The display_options of this HubSpotFormDefinitionPatchRequest.  # noqa: E501
        :type display_options: FormDisplayOptions
        """

        self._display_options = display_options

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HubSpotFormDefinitionPatchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HubSpotFormDefinitionPatchRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.events.configuration import Configuration


class MarketingEventDefaultResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "start_date_time": "datetime",
        "custom_properties": "list[PropertyValue]",
        "event_cancelled": "bool",
        "event_organizer": "str",
        "event_url": "str",
        "event_description": "str",
        "event_name": "str",
        "event_type": "str",
        "event_completed": "bool",
        "end_date_time": "datetime",
        "object_id": "str",
    }

    attribute_map = {
        "start_date_time": "startDateTime",
        "custom_properties": "customProperties",
        "event_cancelled": "eventCancelled",
        "event_organizer": "eventOrganizer",
        "event_url": "eventUrl",
        "event_description": "eventDescription",
        "event_name": "eventName",
        "event_type": "eventType",
        "event_completed": "eventCompleted",
        "end_date_time": "endDateTime",
        "object_id": "objectId",
    }

    def __init__(
        self,
        start_date_time=None,
        custom_properties=None,
        event_cancelled=None,
        event_organizer=None,
        event_url=None,
        event_description=None,
        event_name=None,
        event_type=None,
        event_completed=None,
        end_date_time=None,
        object_id=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """MarketingEventDefaultResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._start_date_time = None
        self._custom_properties = None
        self._event_cancelled = None
        self._event_organizer = None
        self._event_url = None
        self._event_description = None
        self._event_name = None
        self._event_type = None
        self._event_completed = None
        self._end_date_time = None
        self._object_id = None
        self.discriminator = None

        if start_date_time is not None:
            self.start_date_time = start_date_time
        if custom_properties is not None:
            self.custom_properties = custom_properties
        if event_cancelled is not None:
            self.event_cancelled = event_cancelled
        self.event_organizer = event_organizer
        if event_url is not None:
            self.event_url = event_url
        if event_description is not None:
            self.event_description = event_description
        self.event_name = event_name
        if event_type is not None:
            self.event_type = event_type
        if event_completed is not None:
            self.event_completed = event_completed
        if end_date_time is not None:
            self.end_date_time = end_date_time
        if object_id is not None:
            self.object_id = object_id

    @property
    def start_date_time(self):
        """Gets the start_date_time of this MarketingEventDefaultResponse.  # noqa: E501

        The start date and time of the marketing event.  # noqa: E501

        :return: The start_date_time of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date_time

    @start_date_time.setter
    def start_date_time(self, start_date_time):
        """Sets the start_date_time of this MarketingEventDefaultResponse.

        The start date and time of the marketing event.  # noqa: E501

        :param start_date_time: The start_date_time of this MarketingEventDefaultResponse.  # noqa: E501
        :type start_date_time: datetime
        """

        self._start_date_time = start_date_time

    @property
    def custom_properties(self):
        """Gets the custom_properties of this MarketingEventDefaultResponse.  # noqa: E501

        A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account's definition of the MarketingEvent Object. If they don't they will be filtered out and not set. In order to do this you'll need to create a new PropertyGroup on the HubSpot account's MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.   # noqa: E501

        :return: The custom_properties of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: list[PropertyValue]
        """
        return self._custom_properties

    @custom_properties.setter
    def custom_properties(self, custom_properties):
        """Sets the custom_properties of this MarketingEventDefaultResponse.

        A list of PropertyValues. These can be whatever kind of property names and values you want. However, they must already exist on the HubSpot account's definition of the MarketingEvent Object. If they don't they will be filtered out and not set. In order to do this you'll need to create a new PropertyGroup on the HubSpot account's MarketingEvent object for your specific app and create the Custom Property you want to track on that HubSpot account. Do not create any new default properties on the MarketingEvent object as that will apply to all HubSpot accounts.   # noqa: E501

        :param custom_properties: The custom_properties of this MarketingEventDefaultResponse.  # noqa: E501
        :type custom_properties: list[PropertyValue]
        """

        self._custom_properties = custom_properties

    @property
    def event_cancelled(self):
        """Gets the event_cancelled of this MarketingEventDefaultResponse.  # noqa: E501

        Indicates if the marketing event has been cancelled.  # noqa: E501

        :return: The event_cancelled of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: bool
        """
        return self._event_cancelled

    @event_cancelled.setter
    def event_cancelled(self, event_cancelled):
        """Sets the event_cancelled of this MarketingEventDefaultResponse.

        Indicates if the marketing event has been cancelled.  # noqa: E501

        :param event_cancelled: The event_cancelled of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_cancelled: bool
        """

        self._event_cancelled = event_cancelled

    @property
    def event_organizer(self):
        """Gets the event_organizer of this MarketingEventDefaultResponse.  # noqa: E501

        The name of the organizer of the marketing event.  # noqa: E501

        :return: The event_organizer of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_organizer

    @event_organizer.setter
    def event_organizer(self, event_organizer):
        """Sets the event_organizer of this MarketingEventDefaultResponse.

        The name of the organizer of the marketing event.  # noqa: E501

        :param event_organizer: The event_organizer of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_organizer: str
        """
        if self.local_vars_configuration.client_side_validation and event_organizer is None:  # noqa: E501
            raise ValueError("Invalid value for `event_organizer`, must not be `None`")  # noqa: E501

        self._event_organizer = event_organizer

    @property
    def event_url(self):
        """Gets the event_url of this MarketingEventDefaultResponse.  # noqa: E501

        The URL in the external event application where the marketing event can be managed.  # noqa: E501

        :return: The event_url of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_url

    @event_url.setter
    def event_url(self, event_url):
        """Sets the event_url of this MarketingEventDefaultResponse.

        The URL in the external event application where the marketing event can be managed.  # noqa: E501

        :param event_url: The event_url of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_url: str
        """

        self._event_url = event_url

    @property
    def event_description(self):
        """Gets the event_description of this MarketingEventDefaultResponse.  # noqa: E501

        The description of the marketing event.  # noqa: E501

        :return: The event_description of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_description

    @event_description.setter
    def event_description(self, event_description):
        """Sets the event_description of this MarketingEventDefaultResponse.

        The description of the marketing event.  # noqa: E501

        :param event_description: The event_description of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_description: str
        """

        self._event_description = event_description

    @property
    def event_name(self):
        """Gets the event_name of this MarketingEventDefaultResponse.  # noqa: E501

        The name of the marketing event.  # noqa: E501

        :return: The event_name of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this MarketingEventDefaultResponse.

        The name of the marketing event.  # noqa: E501

        :param event_name: The event_name of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_name: str
        """
        if self.local_vars_configuration.client_side_validation and event_name is None:  # noqa: E501
            raise ValueError("Invalid value for `event_name`, must not be `None`")  # noqa: E501

        self._event_name = event_name

    @property
    def event_type(self):
        """Gets the event_type of this MarketingEventDefaultResponse.  # noqa: E501

        The type of the marketing event.  # noqa: E501

        :return: The event_type of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this MarketingEventDefaultResponse.

        The type of the marketing event.  # noqa: E501

        :param event_type: The event_type of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_type: str
        """

        self._event_type = event_type

    @property
    def event_completed(self):
        """Gets the event_completed of this MarketingEventDefaultResponse.  # noqa: E501


        :return: The event_completed of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: bool
        """
        return self._event_completed

    @event_completed.setter
    def event_completed(self, event_completed):
        """Sets the event_completed of this MarketingEventDefaultResponse.


        :param event_completed: The event_completed of this MarketingEventDefaultResponse.  # noqa: E501
        :type event_completed: bool
        """

        self._event_completed = event_completed

    @property
    def end_date_time(self):
        """Gets the end_date_time of this MarketingEventDefaultResponse.  # noqa: E501

        The end date and time of the marketing event.  # noqa: E501

        :return: The end_date_time of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date_time

    @end_date_time.setter
    def end_date_time(self, end_date_time):
        """Sets the end_date_time of this MarketingEventDefaultResponse.

        The end date and time of the marketing event.  # noqa: E501

        :param end_date_time: The end_date_time of this MarketingEventDefaultResponse.  # noqa: E501
        :type end_date_time: datetime
        """

        self._end_date_time = end_date_time

    @property
    def object_id(self):
        """Gets the object_id of this MarketingEventDefaultResponse.  # noqa: E501


        :return: The object_id of this MarketingEventDefaultResponse.  # noqa: E501
        :rtype: str
        """
        return self._object_id

    @object_id.setter
    def object_id(self, object_id):
        """Sets the object_id of this MarketingEventDefaultResponse.


        :param object_id: The object_id of this MarketingEventDefaultResponse.  # noqa: E501
        :type object_id: str
        """

        self._object_id = object_id

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarketingEventDefaultResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MarketingEventDefaultResponse):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.cms.hubdb.api.rows_api import RowsApi
from hubspot.cms.hubdb.api.rows_batch_api import RowsBatchApi
from hubspot.cms.hubdb.api.tables_api import TablesApi



# coding: utf-8

# flake8: noqa
"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.pipelines.models.collection_response_pipeline_no_paging import CollectionResponsePipelineNoPaging
from hubspot.crm.pipelines.models.collection_response_pipeline_stage_no_paging import CollectionResponsePipelineStageNoPaging
from hubspot.crm.pipelines.models.collection_response_public_audit_info_no_paging import CollectionResponsePublicAuditInfoNoPaging
from hubspot.crm.pipelines.models.error import Error
from hubspot.crm.pipelines.models.error_detail import ErrorDetail
from hubspot.crm.pipelines.models.pipeline import Pipeline
from hubspot.crm.pipelines.models.pipeline_input import PipelineInput
from hubspot.crm.pipelines.models.pipeline_patch_input import PipelinePatchInput
from hubspot.crm.pipelines.models.pipeline_stage import PipelineStage
from hubspot.crm.pipelines.models.pipeline_stage_input import PipelineStageInput
from hubspot.crm.pipelines.models.pipeline_stage_patch_input import PipelineStagePatchInput
from hubspot.crm.pipelines.models.public_audit_info import PublicAuditInfo



PAGE_MAX_SIZE = 100
PROPERTY_HISTORY_MAX_SIZE = 50


def fetch_all(get_page_api_client, **kwargs):
    results = []
    after = None

    max_page_size = PROPERTY_HISTORY_MAX_SIZE if "properties_with_history" in kwargs else PAGE_MAX_SIZE
    limit = kwargs.pop("limit", None)
    total_fetched = 0

    while True:
        limit_for_current_page = min(max_page_size, limit - total_fetched) if limit else max_page_size
        page = get_page_api_client.get_page(after=after, limit=limit_for_current_page, **kwargs)

        results.extend(page.results)
        total_fetched += len(page.results)

        if limit and total_fetched >= limit:
            break

        if page.paging is None or page.paging.next is None:
            break

        after = page.paging.next.after

    return results



# coding: utf-8

"""
    Posts

    Use these endpoints for interacting with Blog Posts, Blog Authors, and Blog Tags  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.blogs.blog_posts.configuration import Configuration


class ContentLanguageVariation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "archived_in_dashboard": "bool",
        "created": "datetime",
        "tag_ids": "list[int]",
        "publish_date": "datetime",
        "public_access_rules": "list[object]",
        "password": "str",
        "author_name": "str",
        "public_access_rules_enabled": "bool",
        "name": "str",
        "campaign": "str",
        "id": "int",
        "state": "str",
        "campaign_name": "str",
        "updated": "datetime",
        "slug": "str",
    }

    attribute_map = {
        "archived_in_dashboard": "archivedInDashboard",
        "created": "created",
        "tag_ids": "tagIds",
        "publish_date": "publishDate",
        "public_access_rules": "publicAccessRules",
        "password": "password",
        "author_name": "authorName",
        "public_access_rules_enabled": "publicAccessRulesEnabled",
        "name": "name",
        "campaign": "campaign",
        "id": "id",
        "state": "state",
        "campaign_name": "campaignName",
        "updated": "updated",
        "slug": "slug",
    }

    def __init__(
        self,
        archived_in_dashboard=None,
        created=None,
        tag_ids=None,
        publish_date=None,
        public_access_rules=None,
        password=None,
        author_name=None,
        public_access_rules_enabled=None,
        name=None,
        campaign=None,
        id=None,
        state=None,
        campaign_name=None,
        updated=None,
        slug=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ContentLanguageVariation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._archived_in_dashboard = None
        self._created = None
        self._tag_ids = None
        self._publish_date = None
        self._public_access_rules = None
        self._password = None
        self._author_name = None
        self._public_access_rules_enabled = None
        self._name = None
        self._campaign = None
        self._id = None
        self._state = None
        self._campaign_name = None
        self._updated = None
        self._slug = None
        self.discriminator = None

        self.archived_in_dashboard = archived_in_dashboard
        self.created = created
        if tag_ids is not None:
            self.tag_ids = tag_ids
        self.publish_date = publish_date
        self.public_access_rules = public_access_rules
        self.password = password
        self.author_name = author_name
        self.public_access_rules_enabled = public_access_rules_enabled
        self.name = name
        self.campaign = campaign
        self.id = id
        self.state = state
        self.campaign_name = campaign_name
        self.updated = updated
        self.slug = slug

    @property
    def archived_in_dashboard(self):
        """Gets the archived_in_dashboard of this ContentLanguageVariation.  # noqa: E501


        :return: The archived_in_dashboard of this ContentLanguageVariation.  # noqa: E501
        :rtype: bool
        """
        return self._archived_in_dashboard

    @archived_in_dashboard.setter
    def archived_in_dashboard(self, archived_in_dashboard):
        """Sets the archived_in_dashboard of this ContentLanguageVariation.


        :param archived_in_dashboard: The archived_in_dashboard of this ContentLanguageVariation.  # noqa: E501
        :type archived_in_dashboard: bool
        """
        if self.local_vars_configuration.client_side_validation and archived_in_dashboard is None:  # noqa: E501
            raise ValueError("Invalid value for `archived_in_dashboard`, must not be `None`")  # noqa: E501

        self._archived_in_dashboard = archived_in_dashboard

    @property
    def created(self):
        """Gets the created of this ContentLanguageVariation.  # noqa: E501


        :return: The created of this ContentLanguageVariation.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this ContentLanguageVariation.


        :param created: The created of this ContentLanguageVariation.  # noqa: E501
        :type created: datetime
        """
        if self.local_vars_configuration.client_side_validation and created is None:  # noqa: E501
            raise ValueError("Invalid value for `created`, must not be `None`")  # noqa: E501

        self._created = created

    @property
    def tag_ids(self):
        """Gets the tag_ids of this ContentLanguageVariation.  # noqa: E501


        :return: The tag_ids of this ContentLanguageVariation.  # noqa: E501
        :rtype: list[int]
        """
        return self._tag_ids

    @tag_ids.setter
    def tag_ids(self, tag_ids):
        """Sets the tag_ids of this ContentLanguageVariation.


        :param tag_ids: The tag_ids of this ContentLanguageVariation.  # noqa: E501
        :type tag_ids: list[int]
        """

        self._tag_ids = tag_ids

    @property
    def publish_date(self):
        """Gets the publish_date of this ContentLanguageVariation.  # noqa: E501


        :return: The publish_date of this ContentLanguageVariation.  # noqa: E501
        :rtype: datetime
        """
        return self._publish_date

    @publish_date.setter
    def publish_date(self, publish_date):
        """Sets the publish_date of this ContentLanguageVariation.


        :param publish_date: The publish_date of this ContentLanguageVariation.  # noqa: E501
        :type publish_date: datetime
        """
        if self.local_vars_configuration.client_side_validation and publish_date is None:  # noqa: E501
            raise ValueError("Invalid value for `publish_date`, must not be `None`")  # noqa: E501

        self._publish_date = publish_date

    @property
    def public_access_rules(self):
        """Gets the public_access_rules of this ContentLanguageVariation.  # noqa: E501


        :return: The public_access_rules of this ContentLanguageVariation.  # noqa: E501
        :rtype: list[object]
        """
        return self._public_access_rules

    @public_access_rules.setter
    def public_access_rules(self, public_access_rules):
        """Sets the public_access_rules of this ContentLanguageVariation.


        :param public_access_rules: The public_access_rules of this ContentLanguageVariation.  # noqa: E501
        :type public_access_rules: list[object]
        """
        if self.local_vars_configuration.client_side_validation and public_access_rules is None:  # noqa: E501
            raise ValueError("Invalid value for `public_access_rules`, must not be `None`")  # noqa: E501

        self._public_access_rules = public_access_rules

    @property
    def password(self):
        """Gets the password of this ContentLanguageVariation.  # noqa: E501


        :return: The password of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this ContentLanguageVariation.


        :param password: The password of this ContentLanguageVariation.  # noqa: E501
        :type password: str
        """
        if self.local_vars_configuration.client_side_validation and password is None:  # noqa: E501
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def author_name(self):
        """Gets the author_name of this ContentLanguageVariation.  # noqa: E501


        :return: The author_name of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._author_name

    @author_name.setter
    def author_name(self, author_name):
        """Sets the author_name of this ContentLanguageVariation.


        :param author_name: The author_name of this ContentLanguageVariation.  # noqa: E501
        :type author_name: str
        """
        if self.local_vars_configuration.client_side_validation and author_name is None:  # noqa: E501
            raise ValueError("Invalid value for `author_name`, must not be `None`")  # noqa: E501

        self._author_name = author_name

    @property
    def public_access_rules_enabled(self):
        """Gets the public_access_rules_enabled of this ContentLanguageVariation.  # noqa: E501


        :return: The public_access_rules_enabled of this ContentLanguageVariation.  # noqa: E501
        :rtype: bool
        """
        return self._public_access_rules_enabled

    @public_access_rules_enabled.setter
    def public_access_rules_enabled(self, public_access_rules_enabled):
        """Sets the public_access_rules_enabled of this ContentLanguageVariation.


        :param public_access_rules_enabled: The public_access_rules_enabled of this ContentLanguageVariation.  # noqa: E501
        :type public_access_rules_enabled: bool
        """
        if self.local_vars_configuration.client_side_validation and public_access_rules_enabled is None:  # noqa: E501
            raise ValueError("Invalid value for `public_access_rules_enabled`, must not be `None`")  # noqa: E501

        self._public_access_rules_enabled = public_access_rules_enabled

    @property
    def name(self):
        """Gets the name of this ContentLanguageVariation.  # noqa: E501


        :return: The name of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ContentLanguageVariation.


        :param name: The name of this ContentLanguageVariation.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def campaign(self):
        """Gets the campaign of this ContentLanguageVariation.  # noqa: E501


        :return: The campaign of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._campaign

    @campaign.setter
    def campaign(self, campaign):
        """Sets the campaign of this ContentLanguageVariation.


        :param campaign: The campaign of this ContentLanguageVariation.  # noqa: E501
        :type campaign: str
        """
        if self.local_vars_configuration.client_side_validation and campaign is None:  # noqa: E501
            raise ValueError("Invalid value for `campaign`, must not be `None`")  # noqa: E501

        self._campaign = campaign

    @property
    def id(self):
        """Gets the id of this ContentLanguageVariation.  # noqa: E501


        :return: The id of this ContentLanguageVariation.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ContentLanguageVariation.


        :param id: The id of this ContentLanguageVariation.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def state(self):
        """Gets the state of this ContentLanguageVariation.  # noqa: E501


        :return: The state of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ContentLanguageVariation.


        :param state: The state of this ContentLanguageVariation.  # noqa: E501
        :type state: str
        """
        if self.local_vars_configuration.client_side_validation and state is None:  # noqa: E501
            raise ValueError("Invalid value for `state`, must not be `None`")  # noqa: E501

        self._state = state

    @property
    def campaign_name(self):
        """Gets the campaign_name of this ContentLanguageVariation.  # noqa: E501


        :return: The campaign_name of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this ContentLanguageVariation.


        :param campaign_name: The campaign_name of this ContentLanguageVariation.  # noqa: E501
        :type campaign_name: str
        """
        if self.local_vars_configuration.client_side_validation and campaign_name is None:  # noqa: E501
            raise ValueError("Invalid value for `campaign_name`, must not be `None`")  # noqa: E501

        self._campaign_name = campaign_name

    @property
    def updated(self):
        """Gets the updated of this ContentLanguageVariation.  # noqa: E501


        :return: The updated of this ContentLanguageVariation.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this ContentLanguageVariation.


        :param updated: The updated of this ContentLanguageVariation.  # noqa: E501
        :type updated: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated is None:  # noqa: E501
            raise ValueError("Invalid value for `updated`, must not be `None`")  # noqa: E501

        self._updated = updated

    @property
    def slug(self):
        """Gets the slug of this ContentLanguageVariation.  # noqa: E501


        :return: The slug of this ContentLanguageVariation.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this ContentLanguageVariation.


        :param slug: The slug of this ContentLanguageVariation.  # noqa: E501
        :type slug: str
        """
        if self.local_vars_configuration.client_side_validation and slug is None:  # noqa: E501
            raise ValueError("Invalid value for `slug`, must not be `None`")  # noqa: E501

        self._slug = slug

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContentLanguageVariation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContentLanguageVariation):
            return True

        return self.to_dict() != other.to_dict()
